import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import ReactDropdown from 'react-dropdown';
import { max, scaleSqrt } from 'd3';
import { useMassGeo } from './useMassGeo';
import { useRetentionData } from './useRetentionData';
import { Marks } from './Marks';
import { Dropdown } from './Dropdown';

const width = 960;
const height = 500;

const options = [
  { value: 'all', label: 'All' },
  { value: '0', label: '1st Quartile' },
  { value: '1', label: '2nd Quartile' },
  { value: '2', label: '3rd Quartile' },
  { value: '3', label: '4th Quartile' }
];

const yearOptions = [
  { value: 'all', label: 'All' },
  { value: '2009', label: '2009' },
  { value: '2010', label: '2010' },
  { value: '2011', label: '2011' },
  { value: '2012', label: '2012' },
  { value: '2013', label: '2013' },
  { value: '2014', label: '2014' },
  { value: '2015', label: '2015' },
  { value: '2016', label: '2016' },
  { value: '2017', label: '2017' },
  { value: '2018', label: '2018' }
];

const initialValue = 'all';

const App = () => {
  const MassGeo = useMassGeo();
  const RetentionData = useRetentionData();

  let [data, setData] = useState(null);
  let [selectedCommunityValue, setSelectedCommunityValue] = useState(
    initialValue
  );
  let [selectedyearValue, setSelectedyearValue] = useState(initialValue);

  if (!MassGeo || !RetentionData) {
    return <pre>Loading...</pre>;
  }
  const filteredData = RetentionData.filter(d =>
    selectedCommunityValue === 'all'
      ? d
      : d.communtiy === selectedCommunityValue
  ).filter(d =>
    selectedyearValue === 'all' ? d : d.year === selectedyearValue
  );

  console.log(filteredData[0]);
  const cityname = d => d.City;
  const yearname = d => d.year;
  const sizeValue = d => d.quartile;
  const maxRadius = 20;
  const sizeScale = scaleSqrt()
    .domain([0, max(RetentionData, sizeValue)])
    .range([0, maxRadius]);

  return (
    <>
      <div className="menus-container">
        <span className="dropdown-label">Quartile:</span>
        <ReactDropdown
          options={options}
          value={selectedCommunityValue}
          onChange={({ value }) => setSelectedCommunityValue(value)}
        />
        <span className="dropdown-label">Year:</span>
        <ReactDropdown
          options={yearOptions}
          value={selectedyearValue}
          onChange={({ value }) => setSelectedyearValue(value)}
        />
      </div>
      <svg width={width} height={height}>
        <Marks
          MassGeo={MassGeo}
          RetentionData={filteredData}
          sizeScale={sizeScale}
          sizeValue={sizeValue}
        />
      </svg>
    </>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
